(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     21459,        515]
NotebookOptionsPosition[     19911,        485]
NotebookOutlinePosition[     20472,        506]
CellTagsIndexPosition[     20429,        503]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 19 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"2d715fc9-8403-405a-aef7-f3eda44d8984"],

Cell["Chapter 3, Section 3.13", "Section",
 CellChangeTimes->{{3.858421881612113*^9, 
  3.85842188395088*^9}},ExpressionUUID->"aae59e57-bd88-4b67-bd12-\
7eb0dd618d09"],

Cell[TextData[{
 "We will solve the scaled form of Hill's equations (given in Eqs.(3.226) and \
(3.227)) for the starting values of ",
 StyleBox["x ",
  FontSlant->"Italic"],
 "and",
 StyleBox[" y ",
  FontSlant->"Italic"],
 "using a function ",
 StyleBox["HillsEqns",
  FontWeight->"Bold"],
 ". We calculate the initial ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["y", "."], TraditionalForm]],ExpressionUUID->
  "1b6e4951-66b5-4cf6-b39d-051ef25e008d"],
 " (assuming a circular orbit) and solve the system for ",
 StyleBox["tmax",
  FontSlant->"Italic"],
 " orbital periods.  A list of points is created for each trajectory. "
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8111663982757263`*^9, 3.811166398820459*^9}, {
  3.858413151799652*^9, 3.8584131686874113`*^9}, {3.858414161762147*^9, 
  3.858414274697719*^9}, {3.8584202958957233`*^9, 3.858420350103738*^9}, {
  3.858420380420076*^9, 3.858420387842304*^9}, {3.858420421402734*^9, 
  3.858420456842198*^9}, {3.858420543810822*^9, 3.85842055038416*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"82a645c5-33ab-4e79-9311-1a6682ccbbff"],

Cell[TextData[{
 "For all the starting values we are going to take the initial ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["x", "."], TraditionalForm]],ExpressionUUID->
  "5007c03a-0910-4465-b942-ed0033a2ae98"],
 " = 0 and determine the initial ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["y", "."], TraditionalForm]],ExpressionUUID->
  "10b1e7d0-7e98-4671-94c7-105593035b27"],
 " from ",
 Cell[BoxData[
  FormBox[
   OverscriptBox["y", "."], TraditionalForm]],ExpressionUUID->
  "212b705f-137c-46d7-8330-764f2e4a840f"],
 " = -(3/2)",
 StyleBox["x",
  FontSlant->"Italic"],
 " (using Kepler\[CloseCurlyQuote]s Third Law).  This is equivalent to \
assuming that the initial orbit is circular."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8584132481597633`*^9, 3.858413303254828*^9}, {
  3.8584134974031467`*^9, 3.858413585620843*^9}, {3.8584141457271557`*^9, 
  3.858414152281879*^9}, {3.8584207235667458`*^9, 3.85842073964647*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"3ad5cd7b-47ed-4ca4-9e87-5dfdcbf4fdda"],

Cell[BoxData[
 RowBox[{
  RowBox[{"HillsEqns", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"y0_", ",", " ", "x0_"}], "}"}], ",", "tmax_", ",", " ", 
    RowBox[{"ppoints_", ":", "100"}], ",", " ", 
    RowBox[{"maxsteps_", ":", "\[Infinity]"}]}], "]"}], " ", ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "sol", "}"}], ",", "\n", "  ", 
    RowBox[{
     RowBox[{"sol", " ", "=", " ", 
      RowBox[{"NDSolve", "[", "\n", "  ", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"x", "''"}], "[", "t", "]"}], "-", 
            RowBox[{"2", 
             RowBox[{
              RowBox[{"y", "'"}], "[", "t", "]"}]}]}], " ", "==", "  ", 
           RowBox[{"3", 
            RowBox[{"x", "[", "t", "]"}], "*", 
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{"1", "/", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"Sqrt", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"x", "[", "t", "]"}], "^", "2"}], "+", 
                   RowBox[{
                    RowBox[{"y", "[", "t", "]"}], "^", "2"}]}], "]"}], ")"}], 
                "^", "3"}]}]}], ")"}]}]}], ",", "\n", " ", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"y", "''"}], "[", "t", "]"}], "+", 
            RowBox[{"2", 
             RowBox[{
              RowBox[{"x", "'"}], "[", "t", "]"}]}]}], " ", "==", " ", 
           RowBox[{
            RowBox[{"-", "3"}], 
            RowBox[{
             RowBox[{"y", "[", "t", "]"}], "/", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"Sqrt", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"x", "[", "t", "]"}], "^", "2"}], "+", 
                 RowBox[{
                  RowBox[{"y", "[", "t", "]"}], "^", "2"}]}], "]"}], ")"}], 
              "^", "3"}]}]}]}], ",", "\n", " ", 
          RowBox[{
           RowBox[{"x", "[", "0", "]"}], " ", "==", " ", "x0"}], ",", " ", 
          RowBox[{
           RowBox[{"y", "[", "0", "]"}], " ", "==", " ", "y0"}], ",", " ", 
          RowBox[{
           RowBox[{
            RowBox[{"x", "'"}], "[", "0", "]"}], " ", "==", " ", "0"}], ",", 
          " ", 
          RowBox[{
           RowBox[{
            RowBox[{"y", "'"}], "[", "0", "]"}], " ", "==", " ", 
           RowBox[{
            RowBox[{"-", "1.5"}], "*", "x0"}]}]}], "}"}], ",", "\n", "   ", 
        RowBox[{"{", 
         RowBox[{"x", ",", "y"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"t", ",", "0", ",", 
          RowBox[{"tmax", "*", "2", "\[Pi]"}]}], "}"}], ",", " ", 
        RowBox[{"MaxSteps", "->", "maxsteps"}], ",", 
        RowBox[{"Method", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"\"\<ExplicitRungeKutta\>\"", ",", " ", 
           RowBox[{"\"\<DifferenceOrder\>\"", "\[Rule]", "8"}]}], "}"}]}], 
        ",", " ", 
        RowBox[{"InterpolationOrder", "\[Rule]", "All"}]}], "]"}]}], ";", 
     "\n", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Evaluate", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"y", "[", "t", "]"}], ",", 
            RowBox[{"x", "[", "t", "]"}]}], "}"}], "/.", "sol"}], "]"}], "[", 
        
        RowBox[{"[", "1", "]"}], "]"}], ",", "\n", "   ", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", 
         RowBox[{"tmax", "*", "2", "Pi"}], ",", "0.01"}], "}"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.858341254477353*^9, 3.858341254480685*^9}, {
   3.858413857125127*^9, 3.858413915356556*^9}, {3.8584139623671637`*^9, 
   3.8584139758238983`*^9}, {3.858414013794916*^9, 3.858414112968746*^9}, {
   3.858414600486644*^9, 3.858414601416111*^9}, {3.858414979421073*^9, 
   3.858414987039509*^9}, 3.858415660842903*^9, {3.8584157156534224`*^9, 
   3.858415720213251*^9}, {3.858418626569673*^9, 3.8584186276053867`*^9}, 
   3.858418848422532*^9},
 CellLabel->"In[1]:=",ExpressionUUID->"f8f76eb5-d3f2-4d52-a3b4-2e948a3d6bc4"],

Cell["\<\
Show the locations of the L1 and L2 Lagrange points with red dots, and the \
location of the secondary mass with a + sign.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8111663982757263`*^9, 3.811166398820459*^9}, {
  3.858413151799652*^9, 3.8584131686874113`*^9}, {3.858414161762147*^9, 
  3.858414274697719*^9}, {3.8584202958957233`*^9, 3.858420350103738*^9}, {
  3.858420481306836*^9, 3.858420517230857*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"d144e25d-52b6-4bdc-8ba7-80a29944ba99"],

Cell[BoxData[
 RowBox[{
  RowBox[{"L1", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"PointSize", "[", "0.01", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "1"}]}], "}"}], "]"}]}], "}"}], "]"}]}], ";"}]], "Input",\

 CellChangeTimes->{{3.858340300374712*^9, 3.858340301695406*^9}, {
   3.85834038483961*^9, 3.8583404383898277`*^9}, {3.858340513677389*^9, 
   3.8583405177859097`*^9}, 3.85841468850592*^9},
 CellLabel->"In[2]:=",ExpressionUUID->"7ba31cb2-3f7f-4d79-951d-52df0a13193c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"L2", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{"Red", ",", 
      RowBox[{"PointSize", "[", "0.01", "]"}], ",", 
      RowBox[{"Point", "[", 
       RowBox[{"{", 
        RowBox[{"0", ",", "1"}], "}"}], "]"}]}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.858340300374712*^9, 3.858340301695406*^9}, {
   3.85834038483961*^9, 3.85834044814322*^9}, 3.858414690606515*^9},
 CellLabel->"In[3]:=",ExpressionUUID->"b3f00fa1-5598-49ed-8ea2-590a0a947735"],

Cell[BoxData[
 RowBox[{
  RowBox[{"masscoords", "=", 
   RowBox[{"Graphics", "[", 
    RowBox[{"Text", "[", 
     RowBox[{"\"\<+\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.858340211501493*^9, 3.858340284760294*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"c0c4a7cd-2002-4484-9f6a-8e0385a2ef26"],

Cell[TextData[{
 "We use the ",
 StyleBox["Manipulate",
  FontWeight->"Bold"],
 " function to get the starting values of ",
 StyleBox["x",
  FontSlant->"Italic"],
 " and ",
 StyleBox["y ",
  FontSlant->"Italic"],
 "from the cursor click",
 ".  Only those points on the trajectory within \[PlusMinus]200 in ",
 StyleBox["y",
  FontSlant->"Italic"],
 " and \[PlusMinus]10 in ",
 StyleBox["x",
  FontSlant->"Italic"],
 " are plotted",
 ". "
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8111663982757263`*^9, 3.811166398820459*^9}, {
  3.858413151799652*^9, 3.8584131686874113`*^9}, {3.858414161762147*^9, 
  3.858414274697719*^9}, {3.8584202958957233`*^9, 3.858420350103738*^9}, {
  3.858420481306836*^9, 3.858420636208452*^9}, {3.858420785741493*^9, 
  3.85842079484623*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"91af51c3-407a-45be-9de6-ce67decc2430"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"lp", "=", 
     RowBox[{"ListPlot", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"HillsEqns", "[", 
        RowBox[{"init", ",", "n"}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "200"}], ",", "200"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "8"}], ",", "8"}], "}"}]}], "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"Joined", "->", "True"}], ",", 
       RowBox[{"FrameTicks", "\[Rule]", "None"}], ",", 
       RowBox[{"AspectRatio", "\[Rule]", 
        RowBox[{"1", "/", "2"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
     RowBox[{"masscoords", ",", "L1", ",", "L2", ",", "lp", ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "200"}], ",", "200"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "8"}], ",", "8"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"Frame", "\[Rule]", "True"}], ",", 
      RowBox[{"Joined", "->", "True"}], ",", 
      RowBox[{"FrameTicks", "\[Rule]", "None"}], ",", 
      RowBox[{"AspectRatio", "\[Rule]", 
       RowBox[{"1", "/", "2"}]}]}], "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", "20", ",", "\"\<orbital periods\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "10", ",", "20", ",", "50", ",", "100"}], "}"}], ",", 
     "SetterBar"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"init", ",", 
       RowBox[{"{", 
        RowBox[{"200", ",", "2"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]",
      "Automatic", ",", 
     RowBox[{"ControlType", "\[Rule]", "Locator"}], ",", 
     RowBox[{"LocatorAutoCreate", "\[Rule]", "True"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"AutorunSequencing", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "20"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "6"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "2"}], "}"}]}], "}"}]}], ",", "\[IndentingNewLine]", 
   
   RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8568579443165617`*^9, 3.856857992690118*^9}, {
   3.856858027985859*^9, 3.856858107517982*^9}, {3.856858146112423*^9, 
   3.856858146472308*^9}, {3.856858183281933*^9, 3.856858201746882*^9}, 
   3.856858369088909*^9, {3.856858720615793*^9, 3.8568587345667257`*^9}, {
   3.856858774991539*^9, 3.85685881736707*^9}, 3.856858942504468*^9, {
   3.856859082883869*^9, 3.856859083573614*^9}, {3.856859193673642*^9, 
   3.856859198324471*^9}, {3.8568593391915092`*^9, 3.8568594011103153`*^9}, {
   3.856860050014687*^9, 3.8568600873292437`*^9}, {3.856860117598057*^9, 
   3.8568601247222853`*^9}, {3.856860481763111*^9, 3.856860570891367*^9}, {
   3.85686060750484*^9, 3.856860608165866*^9}, {3.85686064591922*^9, 
   3.8568606933334227`*^9}, 3.8568607290638113`*^9, {3.856860973463066*^9, 
   3.856860978465757*^9}, {3.856861051530189*^9, 3.856861131147975*^9}, {
   3.856862721207686*^9, 3.856862739731029*^9}, {3.856863101910322*^9, 
   3.856863196547063*^9}, {3.856863249976115*^9, 3.856863280966708*^9}, {
   3.8568633931229677`*^9, 3.8568634917326183`*^9}, {3.856863557913953*^9, 
   3.8568635585152197`*^9}, {3.856864541517346*^9, 3.8568645461526957`*^9}, {
   3.856864614598056*^9, 3.856864630468216*^9}, {3.856864854754757*^9, 
   3.856864888337627*^9}, {3.856865385975402*^9, 3.856865387148768*^9}, {
   3.856870931480953*^9, 3.8568710151503572`*^9}, {3.856871110537404*^9, 
   3.856871120210272*^9}, {3.85687117362712*^9, 3.856871178040574*^9}, {
   3.857019369797079*^9, 3.8570193765906*^9}, {3.858414364654745*^9, 
   3.8584144025139637`*^9}, {3.858414487236353*^9, 3.858414489605134*^9}, {
   3.858414552322926*^9, 3.858414569720331*^9}, {3.858414751117395*^9, 
   3.8584148062586107`*^9}, {3.858414880134363*^9, 3.858414926498457*^9}, {
   3.858415086804429*^9, 3.858415106769713*^9}, {3.8584156124780903`*^9, 
   3.8584156221275883`*^9}, {3.858415735408358*^9, 3.8584157388431892`*^9}, {
   3.858420952224305*^9, 3.8584209548486223`*^9}},
 CellLabel->"In[5]:=",ExpressionUUID->"9c1463ae-f924-4a5d-bbe4-09d1d31e3d0d"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`init$$ = {200, 2}, $CellContext`n$$ = 20, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`n$$], 20, "orbital periods"}, {5, 10, 20, 50, 
      100}}, {{
       Hold[$CellContext`init$$], {200, 2}}, Automatic}}, Typeset`size$$ = {
    360., {88., 93.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`init$$ = {200, 2}, $CellContext`n$$ = 20}, 
      "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> ($CellContext`lp = ListPlot[
          $CellContext`HillsEqns[$CellContext`init$$, $CellContext`n$$], 
          PlotRange -> {{-200, 200}, {-8, 8}}, Frame -> True, Joined -> True, 
          FrameTicks -> None, AspectRatio -> 1/2]; 
       Show[$CellContext`masscoords, $CellContext`L1, $CellContext`L2, \
$CellContext`lp, PlotRange -> {{-200, 200}, {-8, 8}}, Frame -> True, Joined -> 
         True, FrameTicks -> None, AspectRatio -> 1/2]), 
      "Specifications" :> {{{$CellContext`n$$, 20, "orbital periods"}, {5, 10,
          20, 50, 100}, ControlType -> 
         SetterBar}, {{$CellContext`init$$, {200, 2}}, Automatic, ControlType -> 
         Locator, LocatorAutoCreate -> True}}, 
      "Options" :> {AutorunSequencing -> {{1, 20}, {2, 6}, {3, 2}}}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{410., {135., 140.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`HillsEqns[{
          Pattern[$CellContext`y0, 
           Blank[]], 
          Pattern[$CellContext`x0, 
           Blank[]]}, 
         Pattern[$CellContext`tmax, 
          Blank[]], 
         Optional[
          Pattern[$CellContext`ppoints, 
           Blank[]], 100], 
         Optional[
          Pattern[$CellContext`maxsteps, 
           Blank[]], Infinity]] := 
       Module[{$CellContext`sol}, $CellContext`sol = 
          NDSolve[{
            Derivative[2][$CellContext`x][$CellContext`t] - 2 
              Derivative[1][$CellContext`y][$CellContext`t] == 
             3 $CellContext`x[$CellContext`t] (1 - 1/
               Sqrt[$CellContext`x[$CellContext`t]^2 + \
$CellContext`y[$CellContext`t]^2]^3), 
             Derivative[2][$CellContext`y][$CellContext`t] + 
              2 Derivative[
                1][$CellContext`x][$CellContext`t] == (-3) \
($CellContext`y[$CellContext`t]/
               Sqrt[$CellContext`x[$CellContext`t]^2 + \
$CellContext`y[$CellContext`t]^2]^3), $CellContext`x[
              0] == $CellContext`x0, $CellContext`y[0] == $CellContext`y0, 
             Derivative[1][$CellContext`x][0] == 0, 
             Derivative[1][$CellContext`y][
              0] == (-1.5) $CellContext`x0}, {$CellContext`x, \
$CellContext`y}, {$CellContext`t, 0, $CellContext`tmax 2 Pi}, 
            MaxSteps -> $CellContext`maxsteps, 
            Method -> {"ExplicitRungeKutta", "DifferenceOrder" -> 8}, 
            InterpolationOrder -> All]; Table[
           Part[
            Evaluate[
             ReplaceAll[{
               $CellContext`y[$CellContext`t], 
               $CellContext`x[$CellContext`t]}, $CellContext`sol]], 
            1], {$CellContext`t, 0, $CellContext`tmax 2 Pi, 
            0.01}]], $CellContext`masscoords = Graphics[
         Text["+", {0, 0}]], $CellContext`L1 = Graphics[{
          RGBColor[1, 0, 0], 
          PointSize[0.01], 
          Point[{0, -1}]}], $CellContext`L2 = Graphics[{
          RGBColor[1, 0, 0], 
          PointSize[0.01], 
          Point[{0, 1}]}]}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.8584148553673677`*^9, {3.858414887933887*^9, 3.858414927627429*^9}, 
   3.85841499270273*^9, 3.858415108783327*^9, 3.8584151580221252`*^9, 
   3.8584156235298862`*^9, 3.858415665103812*^9, 3.858415740237337*^9, 
   3.858415851717486*^9, 3.858416209359187*^9, 3.858417950642255*^9, {
   3.858418638858101*^9, 3.858418660627529*^9}, 3.8584187882985773`*^9, 
   3.858418853573097*^9, 3.858419802543301*^9, {3.858420970712344*^9, 
   3.858420993782337*^9}, 3.858421296675988*^9, 3.890903285417075*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"10842baa-c474-452b-98d3-024ffcd26570"]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{919, 639},
WindowMargins->{{249, Automatic}, {Automatic, 135}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"1c4bdddc-b9de-42bc-b7e8-d8065f30d8c6"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 387, 8, 53, "Text",ExpressionUUID->"2d715fc9-8403-405a-aef7-f3eda44d8984"],
Cell[948, 30, 167, 3, 67, "Section",ExpressionUUID->"aae59e57-bd88-4b67-bd12-7eb0dd618d09"],
Cell[1118, 35, 1109, 28, 95, "Text",ExpressionUUID->"82a645c5-33ab-4e79-9311-1a6682ccbbff"],
Cell[2230, 65, 1035, 27, 76, "Text",ExpressionUUID->"3ad5cd7b-47ed-4ca4-9e87-5dfdcbf4fdda"],
Cell[3268, 94, 4188, 107, 241, "Input",ExpressionUUID->"f8f76eb5-d3f2-4d52-a3b4-2e948a3d6bc4"],
Cell[7459, 203, 521, 10, 53, "Text",ExpressionUUID->"d144e25d-52b6-4bdc-8ba7-80a29944ba99"],
Cell[7983, 215, 598, 15, 30, "Input",ExpressionUUID->"7ba31cb2-3f7f-4d79-951d-52df0a13193c"],
Cell[8584, 232, 520, 13, 30, "Input",ExpressionUUID->"b3f00fa1-5598-49ed-8ea2-590a0a947735"],
Cell[9107, 247, 378, 9, 30, "Input",ExpressionUUID->"c0c4a7cd-2002-4484-9f6a-8e0385a2ef26"],
Cell[9488, 258, 872, 27, 76, "Text",ExpressionUUID->"91af51c3-407a-45be-9de6-ce67decc2430"],
Cell[10363, 287, 4566, 94, 241, "Input",ExpressionUUID->"9c1463ae-f924-4a5d-bbe4-09d1d31e3d0d"],
Cell[14932, 383, 4975, 100, 294, "Output",ExpressionUUID->"10842baa-c474-452b-98d3-024ffcd26570"]
}
]
*)

